#! /usr/bin/python3 -s
"""Delete dynamic analysis from VMRay Analyzer database"""


import argparse
import os
import sys


FILE = os.path.abspath(os.path.realpath(__file__))


try:
    # try to import VMRay REST API
    from vmray.rest_api import VMRayRESTAPI
except ImportError:
    # if VMRAY REST API is not installed, try relative import
    sys.path.append(os.path.join(os.path.dirname(FILE), ".."))
    from vmray.rest_api import VMRayRESTAPI


def delete_analysis(api, args):
    print("Deleting analysis with ID {}".format(args.analysis_id))
    api.call("DELETE", "/rest/analysis/{}".format(args.analysis_id))


def main():
    # set up argument parser
    parser = argparse.ArgumentParser(description="Delete dynamic analysis from VMRay Analyzer database")

    # arguments
    parser.add_argument("server", type=str, help="Server address")
    parser.add_argument("api_key", type=str, help="API key to use")
    parser.add_argument("--no_verify", "-n", action="store_true", help="Do not verify SSL certificate")

    parser.add_argument("analysis_id", type=int, help="Analysis ID")

    # parse args
    args = parser.parse_args()

    # create VMRay REST API object
    api = VMRayRESTAPI(args.server, args.api_key, not args.no_verify)

    # perform API call
    return delete_analysis(api, args)


if __name__ == "__main__":
    main()
