#! /usr/bin/python3 -s
"""Download VMRay Analyzer analysis archive"""


import argparse
import io
import os
import sys


FILE = os.path.abspath(os.path.realpath(__file__))


try:
    # try to import VMRay REST API
    from vmray.rest_api import VMRayRESTAPI
except ImportError:
    # if VMRAY REST API is not installed, try relative import
    sys.path.append(os.path.join(os.path.dirname(FILE), ".."))
    from vmray.rest_api import VMRayRESTAPI


def download_analysis_archive(api, args):
    print("Downloading analysis archive")
    data = api.call("GET", "/rest/analysis/{}/archive".format(args.analysis_id), raw_data=True)

    print("Writing data to file")
    with io.open(args.filename, "wb") as fobj:
        fobj.write(data.read())


def main():
    # set up argument parser
    parser = argparse.ArgumentParser(description="Download VMRay analyzer analysis archive")

    # arguments
    parser.add_argument("server", type=str, help="Server address")
    parser.add_argument("api_key", type=str, help="API key to use")
    parser.add_argument("--no_verify", "-n", action="store_true", help="Do not verify SSL certificate")

    parser.add_argument("analysis_id", type=int, help="Analysis ID")
    parser.add_argument("filename", type=str, help="Local filename of ZIP archive")

    # parse args
    args = parser.parse_args()

    # create VMRay REST API object
    api = VMRayRESTAPI(args.server, args.api_key, not args.no_verify)

    # perform API call
    return download_analysis_archive(api, args)


if __name__ == "__main__":
    main()
